#
# spec file for package guvcview
#
# Copyright (c) 2012 Malcolm J Lewis <malcolmlewis@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


Name:           guvcview
Version:        1.7.0
Release:        3.6
License:        GPL-3.0
# Reference to GPL-2.0 in some files?
Summary:        GTK+ UVC Viewer and Capturer
Url:            http://guvcview.sourceforge.net/
Group:          Productivity/Multimedia/Video/Players
Source0:        http://voxel.dl.sourceforge.net/project/guvcview/source/%{name}-src-%{version}.tar.gz
BuildRequires:  SDL-devel
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  libffmpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  libudev-devel
BuildRequires:  libv4l-devel
BuildRequires:  linux-glibc-devel
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%lang_package

%prep
%setup -q -n %{name}-src-%{version}
chmod -x ChangeLog

%build
CPPFLAGS=-I/usr/include/ffmpeg
export CPPFLAGS
%configure --disable-debian-menu \
	   --disable-desktop
make %{?_smp_mflags}

%install
%make_install
# Remove installed documentation
pushd %{buildroot}%{_datadir}/doc
rm -rf %{name}
popd
# Create desktop file as disabled during build
%suse_update_desktop_file -c %{name} "A video viewer and capturer for the linux uvc driver" %{name} %{name} %{name} AudioVideo AudioVideoEditing
pushd %{buildroot}%{_datadir}/pixmaps
cp %{name}/%{name}.png .
popd
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%{_bindir}/%{name}
%dir %{_datadir}/pixmaps/%{name}
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/pixmaps/%{name}/*.png
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/*.gz

%files lang -f %{name}.lang

%changelog
* Tue Jul 30 2013 i@margueirte.su
- build against libffmpeg-devel.
* Sat Jul 20 2013 zaitor@opensuse.org
- Update to version 1.7.0:
  + Refactor avi muxer (base it on libav muxer with opendml
    support).
  + Refactor mkv muxer (base it on libav muxer with webm support).
  + Add VP8, Theora and Vorbis codecs.
  + Add Webm support.
  + Add a Top Menu.
  + Move all file operations to the Top Menu.
* Thu Sep 20 2012 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix build with latest libavcodec.
  + Fix audio codecs listing.
  + Fix audio codecs (AC3 and AAC) input format for latest
    libavcodec API (float).
  + Add support for delayed frames in video encoding.
- Changes since version 1.6.0:
  + Run audio in separate thread.
  + Update audio buffer.
  + Move pulse audio interface from simple to async API.
  + Add pulse device list.
  + Enable build of pulse API by default.
- Added new build dependency, intltool.
* Sun May 20 2012 zaitor@opensuse.org
- Update to version 1.5.3:
  + Update libavcodec API.
  + Add libavutil dependency.
  + Fix pulse interface.
  + Update language catalogs.
- Drop guvcview-pulseaudio-fix.patch, fixed upstream.
- Change BuildRequires: pulseaudio-devel to libpulse-devel.
* Sun Feb 26 2012 zaitor@opensuse.org
- Update to version 1.5.2:
  + Move to pthreads (fix gthread API 2 issues).
  + Add italian translation.
  + Fix several libavcodec issues.
  + Fix some gtk3 widgets.
- Drop guvcview-fix-glib-include.patch, fixed upstream.
- Add guvcview-pulseaudio-fix.patch: Fix pulseaudio interface.
* Mon Jan 23 2012 malcolmlewis@opensuse.org
- Updated to version 1.5.1:
  + Moved to gtk3.
  + Make control window size dependent on screen resolution.
  + Threaded coding patch - George Sedov <radist.morse@gmail.com>.
  + Fix h264 codec properties.
- Updates from version 1.5.0:
  + Add a no display mode (--no_display).
  + Fix build issues with newer versions (>=0.7.x) of ffmpeg
    libavcodec.
  + Add support for unix signals.
  + Add VU meter OSD.
  + Fix menu controls (linux 3.0).
- Add guvcview-fix-glib-include.patch: To fix only <glib.h> can be
  included directly error for builds > 1210.
* Mon Oct  3 2011 malcolmlewis@opensuse.org
- Fix guvcview.desktop file in spec file.
* Fri Jul  1 2011 malcolmlewis@opensuse.org
- Initial build based on fc15 spec file.
